%%Main m-file for Labor Market Participation and Minimum Wage Policy
% Author: Adrian Masters and Ben Griffy
% Date: July 2020

clear all
close all
clc

%%Data and paths
externrun = 'y';
codedir = pwd;

if externrun == 'n'
    projdir    = codedir;
    input_path = '../modeluse_data';
else
    projdir    = codedir;
    input_path = '../data';
end

output_path = fileparts('/output/');
graphics_path = fileparts('/graphics/');
SMM_path = fileparts('/SMM/');
results_path = fileparts('/results/');

%------------------%
% Options
%------------------%
opts = struct('SMM','n', ... % Calibrate the model using the decentralized equilibrium with wbar given
              'solveLaissezFaire','y', ... % UI expansion in general equilibrium
              'solvePlanner','y', ... % Solve for optimal pbar in planner's problem
              'solveDecentral','y', ... % Solve for optimal wbar in decentralized equilibrium
              'solveCalibrated','y', ... % Solve for optimal wbar in decentralized equilibrium
              'decompExperiments','y', ... % Perform decomposition experiments
              'policyExperiments','y', ... % Conduct policy experiments
              'policyUI','y', ... % UI expansion in partial equilibrium
              'policyMW','y', ... % optimal minimum wage
              'policyBoth','y', ... % optimize both MW and UI at the same time
              'CalcTrans','y', ... % Calculate welfare in the steady state or calculate over the transition
              'CompDecompPolicies','y', ... % compare equilibrium for different decompositions
              'CompPolicyExperiments','y', ... % compare equilibrium of different policies
              'SaveEstimOutput','y', ... % save best parameters in csv and table as well as non-targeted moments
              'solver','DR', ... % Solver for calibration (FS: fminsearch, SA: simulated annealing, PS: pattern search, DR: DiRect)
              'params','loadparams', ... % if "loadparams" this loads the minimum distance parameters from previous SMM estimation. Any other name starts with the default below.
              'SMM_path',SMM_path, ... % set the SMM path to save estimation results
              'results_path',results_path, ... % set the path to save final results
              'graphics_path',graphics_path, ... % set the path to save diagnostic graphics. Note: this is NOT final results
              'output_path',output_path, ... % set the path to save decision rules
              'input_path',input_path, ... % set the path to read in data to create 
              'proj_dir',projdir);

%------------------%
%Model Parameters
%------------------%

% Default Parameters:
params = struct('r',0.00327, ... % discount rate
                'llambda',0.0326, ... % exogenous separation rate
                'mbar',1, ...
                'eeta',0.5, ... % matching elasticity
                'bbeta',0.52253086, ... % bargaining power (estimated)
                'mmu',2.5, ... % "mean parameter" of the log-normal
                'ssigma',0.37222222, ... % s.d parameter
                'm',1, ... % scale parmater on the matching function
                'pphi',0.0, ... % this is from a previous version of the model. can use this to add a replacement rate for p.
                'pphiDelt',2, ... % this is from a previous version of the model and does nothing
                'z',2.2777778, ... % subsistence benefits
                'zDelt',2, ... % change in subsistence benefits (approx. UBI?)
                'a',98.209877, ... % vacancy creation/advertising cost
                'eplb',0, ...
                'pmax',1, ...
                'NP',1000, ...
                'NEpsTot',1000, ...
                'NEps1',100, ...
                'NEps2',10, ...
                'NEps3',1000, ...
                'NElast',100, ...
                'TTrans',2400, ...
                'TTransMax',200, ...
                'wbarDelt',1.00, ...
                'wbar',7.25); % initial minimum wage

smm_params = cellstr({'ssigma','mmu','a','bbeta','z'}); % parameters to be calibrated from the data

%----------------------%
% Simulation Parameters
%----------------------%

 %       'ssigma','mmu','a','bbeta','z'
    LB = [0.1,    1.0,  30,   0.15,  1.0];
    UB = [0.4,    4.0,  200,  1.0,  10.0];
    Aeq = [];
    Beq = [];
    A = [];
    B = [];

SMMopts = struct('A',A,'B',B,'LB',LB, ...
                 'UB',UB,'Aeq',Aeq,'Beq',Beq,'SMM_params',smm_params);


%----------------------------%
% Simulated Method of Moments
%----------------------------%

% Get the set of moments to match
[moments,resultsSeries] = get_data(projdir,input_path,opts);

params.wbinDelt = (resultsSeries.empWageDistWide(2,1) - resultsSeries.empWageDistWide(1,1))./2;

distMoments = resultsSeries.empWageDistWide;

%----------------------------%
% Simulated Method of Moments
%----------------------------%

% Get the set of moments to match
[params] = get_params(projdir,SMM_path,opts,params);


max_params = Main_Wrapper(params,opts,SMMopts,moments,distMoments,resultsSeries)
