function eqm = Model(x,params,order,opts,solveOpts)
%%Model m-file for Labor Market Participation and the Minimum Wage
%Author: Adrian Masters and Ben Griffy
%Date: July 2020

% inputs
% x(1): market tightness (theta)
% x(2): cut-off productivity in planner's problem, minimum wage in decentralized problem.


[pphi,eeta,bbeta,a,z,r,llambda,m,mmu,ssigma,lb,ub,pphiDelt,zDelt,wbarDelt,wbinDelt,N,T,wbar,mFun,dmFun,wageFun,pFun,udotFun] = Parameters(params, order, opts);

if strcmpi(solveOpts.prob,'planner') || strcmpi(solveOpts.prob,'plannerfixed')

    eqm=zeros(2,1);

    if x(1)<=0 || x(2)<z/(1-pphi)
        eqm=10000*ones(2,1);
        % eqm = NaN
        % err = 1
        return
    end


    E=LNCalcExp(params,order,opts,x(2),inf);    % expected prod above w

    matRate = mFun(x(1));
    dmatRate = dmFun(x(1));

    % consistent with paper, eq 3
    eqm(1)=dmatRate*((1-pphi)*E-z)-a*(r+llambda+matRate*(1-eeta));

    % consistent with paper, eq 4
    eqm(2)=dmatRate*(1-pphi)*(matRate*x(2)+llambda*E)-(matRate+llambda)*(a*llambda+z*dmatRate);


    % ssr = eqm'*eye(2)*eqm;

elseif strcmpi(solveOpts.prob,'decentralparticipation') || strcmpi(solveOpts.prob,'decentralparticipationfixed')

    eqm=zeros(2,1);

    if x(1)<=0 || x(2)<z/(1-pphi)
        eqm=10000*ones(2,1);
        % eqm=NaN
        % err = 1
        return
    end

    % matching rate at theta* and derivative of matching function at theta*
    matRate = mFun(x(1));
    dmatRate = dmFun(x(1));


    % convenient definitions
    rl=r+llambda;
    rlm=r+llambda+matRate;
    lm=llambda+matRate;
    rm=r+matRate;
    rlbm=r+llambda+bbeta*matRate;



    % ps = pFun(x(2),x(1));

    Fbar=logncdf(x(2),mmu,ssigma);  % cum dist vlaue at wbar
    fbar=lognpdf(x(2),mmu,ssigma);     % density at wbar
    Ebar=LNCalcExp(params,order,opts,x(2),inf);    % expected prod above wbar



    % eq. 10 in sect. 3 of EER submission
    eqm(1)=matRate*(1-bbeta)*((1-pphi)*Ebar-z)-a*x(1)*rlbm;  % free entry condition(Ah.2.4)


    % new version

    dHdph=-fbar*((1-pphi)*(rlm*matRate*x(2)+r*llambda*Ebar)-lm*(llambda*x(1)*a+rm*z));     %S.3.6 with denominator cancelled out
                                                                                    % modified after sign error

    dHdt=(1-Fbar)*llambda*(dmatRate*((1-pphi)*Ebar-z)-a*(rlm-x(1)*dmatRate));   % S.4.3 with denominator cancelled out

    dGdph=matRate*(1-bbeta)*(1-pphi)*(fbar*(Ebar-x(2)))/(1-Fbar);     % Ah.3.6

    dGdt=dmatRate*(1-bbeta)*((1-pphi)*Ebar-z)-a*(rlbm+bbeta*dmatRate*x(1));    % Ah.3.5

    dtdw=-(dGdph/dGdt);    % S.4.4

    eqm(2)=dHdph+dHdt*dtdw;    % S.3.1

else % decentralized problem

    eqm=zeros(2,1);

    if x(1)<=0 || x(2)<z/(1-pphi)
        eqm=10000*ones(2,1)
        % eqm=NaN
        % err = 1
        return
    end

    % matching rate at theta* and derivative of matching function at theta*
    matRate = mFun(x(1));
    dmatRate = dmFun(x(1));


    % convenient definitions
    rl=r+llambda;
    rlm=r+llambda+matRate;
    lm=llambda+matRate;
    rm=r+matRate;
    rlbm=r+llambda+bbeta*matRate;

    DENps=(bbeta*rlm)+(1-bbeta)*rl*pphi;


    ps=(rlbm*x(2)-(1-bbeta)*rl*z)/DENps;   %psquigle see p.(R.8)

    % ps = pFun(x(2),x(1));

    Fbar=logncdf(x(2),mmu,ssigma);  % cum dist vlaue at wbar
    Fsq=logncdf(ps,mmu,ssigma);  % cum dist as psquigle

    fbar=lognpdf(x(2),mmu,ssigma);     % density at wbar

    Ebar=LNCalcExp(params,order,opts,x(2),inf);    % expected prod above wbar
    Esq=LNCalcExp(params,order,opts,ps,inf);    % expected prod above psquigle


    % eq. 10 in sect. 3 of EER submission
    eqm(1)=matRate*(((integral(@(x)LNInt(x,mmu,ssigma),x(2),ps)*((ssigma*(2*pi)^(1/2))^-1)-(Fsq-Fbar)*x(2))/rl)+...
               (1-bbeta)*((1-pphi)*Esq-z)*(1-Fsq)/rlbm)-a*x(1)*(1-Fbar);  % (R.8.3) as modified in  (T.1.2)
    
    % new version

    % line 1 of eq. 35 in sect. 9.3 of EER submission. Missing second line?
    dHdw=-fbar*((1-pphi)*(rlm*matRate*x(2)+r*llambda*Ebar)-lm*(llambda*x(1)*a+rm*z));     %S.3.6 with denominator cancelled out

    %
    dHdt=(1-Fbar)*llambda*(dmatRate*((1-pphi)*Ebar-z)-a*(rlm-x(1)*dmatRate));   % S.4.3 with denominator cancelled out

    dGdw=((1-Fbar)^-1)*(fbar*a-matRate*(Fsq-Fbar)/(rl*x(1)));     % S.4.7 (typo in original corrected)

    dGdt=((eeta-1)*a/x(1))-bbeta*(1-bbeta)*dmatRate*matRate*((1-pphi)*Esq-z)*(1-Fsq)/...
         (x(1)*rlbm^2*(1-Fbar));        % S.5.% as modified in T.1.3

    dtdw=-(dGdw/dGdt);    % S.4.4

    % eqm(2)=dHdw+dHdt*dtdw;    % S.3.1

    eqm(2)=dHdw+dHdt*dtdw;    % S.3.1


end

if strcmpi(solveOpts.prob,'calib') || strcmpi(solveOpts.prob,'decentralfixed') || strcmpi(solveOpts.prob,'decentralparticipationfixed') || strcmpi(solveOpts.prob,'plannerfixed')
    eqm = eqm(1);
end

% eqm;

end
